%%% Copyright (c) 1998
%%% School of Computing
%%% National University of Singapore
%%% Project: InteGrate

%%% Last modified: $Date: 1998/11/12 09:10:50 $ by $Author: huyl $
%%% Version: $Revision: 1.33 $

%%%  Description: general constants

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Title (appears in all toplevel windows)
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Title = 'Gate Machine I'

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Paths to find data and bitmaps
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% path to the home of the Gate Machine
HomePath =
\ifdef WINDOWS
\insert windowspath
\else
{OS.getEnv "HOME"}
#
"/Oz/integrate/"
\end

BitmapPath = HomePath#'bitmaps/'
DataPath = HomePath#'src/data/'
CPILinkPath = HomePath#'cpi/'
WSATOIPLinkPath = HomePath#'WSATOIP/'

%% my favorite editor
Editor = "emacs"

%% %%%%%%%%%%%%%%%%%%%
%% Numerical Constants
%% %%%%%%%%%%%%%%%%%%%

HoursPerDay = 24
MinutesPerHour = 60
MinutesPerDay = HoursPerDay*MinutesPerHour

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Planning-related constants
%% (will become parameters in problem description
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% threshold for duration of stay for splitting into
%% arrival, remote, departure --- in minutes

RemotingThreshold = 300

%% length of arrival and departure stay of flights
%% that are split up --- in minutes
RemotingArrivalLength = 60
RemotingDepartureLength = 120

%% Distance parameters
DistanceFlightUnknown=0  % distance if to-flight is unknown
DistanceNoInfo=0         % distance if bay distance data
                         % has no entry for given bays
                         % (e.g. one of them is remote)

%% Flight Prefer Bays (ground handlers preferences) parameter
GroundHandlersUnknown=0  % Not implemented yet
GroundHandlersDefault=0

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Appearence of Main Windows
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ActiveFrameTextColor = blue
ActiveColor =    black
InactiveColor = 'SlateGray'

NormalFontSize = 140
FontFamily        = '-*-helvetica-medium-r-normal--*-'
BoldFontFamily  =   '-*-helvetica-bold-r-normal--*-'

FontMatch       = '-*-*-*-*-*-*'

NormalFont  = FontFamily     # NormalFontSize # FontMatch
BoldFont    = BoldFontFamily # NormalFontSize # FontMatch

DefaultButtonWidth = 8
DefaultLabelWidth  = 8
BigPad             = 4
Border             = 3
ScrollerWidth      = 13

FlowchartCanvasItems=
items(
      data:
	 pos(x:0 y:0 text:'Data' next:[task])
      constraints:
	 pos(x:2 y:0 text:'Constraints' next:[task])
      task:
	 pos(x:1 y:1 text:'Load Task' next:[fdSolver lsSolver])
      fdSolver:
	 pos(x:0 y:2 text:'CP' next:[solution])
      lsSolver:
	 pos(x:2 y:2 text:'Local Search' next:[solution])
      solution:
	 pos(x:1 y:3 text:'Committed Solution' next:[fdReplanner lsReplanner])
      fdReplanner:
	 pos(x:0 y:4 text:'CP Replanner' next:nil)
      lsReplanner:
	 pos(x:2 y:4 text:'LS Replanner' next:nil)
     )
   
FlowchartCanvasConstants=
constants(
	  xBorder: 90
	  yTopBorder: 50
	  yBottomBorder: 0
	  factor: 100
	  textWidth: 30
	  height: 5*FlowchartCanvasConstants.factor
	  +FlowchartCanvasConstants.yTopBorder+FlowchartCanvasConstants.yBottomBorder
	  width : 380
	  items: {Record.map FlowchartCanvasItems
		  fun {$ R}
		     {Adjoin R
		      pos(x: R.x * FlowchartCanvasConstants.factor
			  + FlowchartCanvasConstants.xBorder
			  y: R.y * FlowchartCanvasConstants.factor
			  + FlowchartCanvasConstants.yTopBorder)}
		  end}
	  circleRadius : 30
	 )

RightCanvasWidth=440

ItemWidth = 120
ItemHeight=22
ItemTextYOffset= 9 %20
ItemTextXOffset= 20 %120

WindowHeightMax = 300

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Appearence of Gantt Chart
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

GanttHourWidth = 100
GanttArrivalXOffset = 20
GanttDepartureXOffset = 20

GanttBayNamesCanvasWidth = 80
GanttEntryTextXOffset = 10
GanttEntryTextYOffset = 10

GanttTimeCanvasHeight = 20
GanttEntryHeight = 20

Resolution = 0.00001
DefScrInc = 4

/* %%next parameters will be obtained from WinparaDialog class and
   %%tk constants in task.oz: ganttCanvasWidth and ganttCanvasHeight
GanttCanvasHeight = 500
GanttCanvasWidth = 600
GanttCanvasCenter = GanttCanvasWidth div 2
GanttCanvasMinutes = GanttCanvasWidth * MinutesPerHour div GanttHourWidth
*/

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Appearence of Airport Window
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

AirportBayColors = colors(fixed:red
			  remote:green
			  bus:black)

AirportBayCircleRadius = 8

AirportBayNameOffsetFactor = ~4     % bay name goes to terminal side
AirportFlightNameOffsetFactor = 12  % flight name goes to apron side

%% Scaling

AirportMinScale = 0.55
AirportMaxScale = 5.00
AirportDefScale = 1.00

AirportXMax = 1800
AirportXMaxFloat = {Int.toFloat AirportXMax}
AirportYMax = 1200
AirportYMaxFloat = {Int.toFloat AirportYMax}

%%AirportCanvasWidth =  900
%%AirportCanvasHeight = 700

local
   Straight=
   p(2 2 15 15  2  2  7  7  1)#
   p(2 7 16 19 16 20 25 27 25)

   Slanted=
   p(0 5  3  5 12 15 15 17 20)#
   p(3 8 24 26 15 18 23 25 21)
in
   AirportAircraftProfile=airportAircraftProfile(n: Straight
						 s: Straight
						 w: Straight
						 e: Straight
						 nw: Slanted
						 sw: Slanted
						 ne: Slanted
						 se: Slanted)
end
    
AirportOrientationFactors=factors(n: ~1# 0   #    0# 1   #   1# 0   #    0# 1
				  s: ~1# 0   #    0#~1   #   1# 0   #    0#~1
				  w:  0# 1   #   ~1# 0   #   0# 1   #    1# 0  
				  e:  0#~1   #   ~1# 0   #   0#~1   #    1# 0
				  sw: 1# 0   #    0#~1   #   0# 1   #   ~1# 0
				  se:~1# 0   #    0#~1   #   0#~1   #   ~1# 0
				  nw: 1# 0   #    0# 1   #   0# 1   #    1# 0
				  ne:~1# 0   #    0# 1   #   0#~1   #    1# 0
				 )



















