%%%  Programming Systems Lab, DFKI Saarbruecken,
%%%  Stuhlsatzenhausweg 3, D-66123 Saarbruecken, Phone (+49) 681 302-5312
%%%  Author: Christian Schulte
%%%  Email: schulte@dfki.uni-sb.de
%%%  Last modified: $Date: 1996/11/27 22:56:29 $ by $Author: schulte $
%%%  Version: $Revision: 1.3 $

local

   %% Parameters
   BitMapDir     = {System.get home}#'/demo/bitmaps/animated-queens/' 
   WinTitle      = 'N-Queens'
   ExplorerTitle = 'Draw '#WinTitle
   MaxWidth      = 600
   BlackColor    #
   WhiteColor    #
   QueenColor    #
   CrossColor    = case Tk.isColor then gray85#gray95#darkorange1#gray75
		   else black#white#black#black
		   end

   %% Derived Parameters
   WidthByMag    = s(micro:2 tiny:5 small:10 middle:25 large:50)
   QueenByMag    = q(micro:  {New Tk.image
			      tkInit(type:bitmap foreground:QueenColor
				     file:BitMapDir#'micro-queen.xbm')}
		     tiny:   {New Tk.image
			      tkInit(type:bitmap foreground:QueenColor
				     file:BitMapDir#'tiny-queen.xbm')}
		     small:  {New Tk.image
			      tkInit(type:bitmap foreground:QueenColor
				     file:BitMapDir#'small-queen.xbm')}
		     middle: {New Tk.image
			      tkInit(type:bitmap foreground:QueenColor
				     file:BitMapDir#'middle-queen.xbm')}
		     large:  {New Tk.image
			      tkInit(type:bitmap foreground:QueenColor
				     file:BitMapDir#'large-queen.xbm')})
   CrossByMag    = c(micro:  unit
		     tiny:   unit
		     small:  unit
		     middle: {New Tk.image
			      tkInit(type:bitmap foreground:CrossColor 
				     file:BitMapDir#'middle-cross.xbm')}
		     large:  {New Tk.image
			      tkInit(type:bitmap foreground:CrossColor
				     file:BitMapDir#'large-cross.xbm')})
   StippleSuffix = case Tk.isColor then '-solid.xbm' else '-gray.xbm' end
   StippleByMag  = c(micro:  '@'#BitMapDir#micro #StippleSuffix
		     tiny:   '@'#BitMapDir#tiny  #StippleSuffix
		     small:  '@'#BitMapDir#small #StippleSuffix
		     middle: '@'#BitMapDir#middle#StippleSuffix
		     large:  '@'#BitMapDir#large #StippleSuffix)


   fun {Comp I W Js}
      case Js of nil then {List.number I W 1}
      [] J|Jr then
	 case J==I then {Comp I+1 W Jr} else I|{Comp I+1 W Js} end
      end
   end
   
   class QueensBoard
      from Tk.canvas

      meth init(parent:P vector:V)
	 S = {Width V}
	 M = case     S*WidthByMag.large =<MaxWidth then large
	     elsecase S*WidthByMag.middle=<MaxWidth then middle
	     elsecase S*WidthByMag.small =<MaxWidth then small
	     elsecase S*WidthByMag.tiny  =<MaxWidth then tiny
	     else micro
	     end
	 W = WidthByMag.M
	 C = CrossByMag.M
	 Q = QueenByMag.M
      in
	 Tk.canvas, tkInit(parent:P width:S*W height:S*W bg:WhiteColor)
	 %% Draw chess board squares
	 Tk.canvas, tk(crea rectangle 0 0 S*W S*W
		       stipple:StippleByMag.M fill:BlackColor outline:'')
	 %% Draw queens
	 {For 1 S 1
	  proc {$ X} Y=V.X in
	     case {IsDet Y} then {self draw(X Y W Q)} else skip end
	  end}
	 %% Draw crosses
	 case C==unit then skip else
	    {For 1 S 1
	     proc {$ X} Y=V.X in
		case {IsFree Y} then skip else
		   {ForAll {Comp 1 W case {IsDet Y} then [Y]
				     else {FD.reflect.domList Y}
				     end}
		    proc {$ Y}
		       {self draw(X Y W C)}
		    end}
		end
	     end}	    
	 end
      end

      meth draw(X Y W I)
	 Tk.canvas,tk(crea image (X-1)*W (Y-1)*W image:I anchor:nw)
      end

   end

in

   {Explorer add(information separator)}
   {Explorer add(information
		 fun {$ N S}
		    V=case {IsList S} then {List.toTuple '#' S} else S end
		    W={New Tk.toplevel tkInit(title:WinTitle#' ('#N#')')}
		    B={New QueensBoard init(parent:W vector:V)}
		 in
		    {Tk.send pack(B)}
		    W#tkClose
		 end
		 label:ExplorerTitle)}

end
