\feed prelude

declare

\insert constants
\insert tkaux

\insert timetabling/main
\insert bridge/main

proc {Empty X Y} skip end

MoneyFont="-*-Courier New-normal-r-r*-*-200-180-*-*-c-*-*-ansi-"

fun {ML Root L}
   Dom={FD.reflect.dom Root.L}
   Desc={FoldL Dom fun {$ Acc X}
		      Acc # ' ' #
		      case X of Low#High then Low#'..'#High
		      else X end
		   end '{'}
in
   label(text:L#Desc#' } '
	 font:MoneyFont)
end
fun {TL L}
   label(text:L font:MoneyFont)
end

Window={New Tk.toplevel tkInit(title:'starting'
			       withdraw: true)}

[
  demo(text:'SAT, no pruning'
       script:
	  proc {$ X}
		  [V1 V2]=X
	       in
		  X:::0#1
		  {FD.distribute naive X}
		  {FD.disj {FD.nega V1} V2 1}
		  {FD.disj V1 {FD.nega V2} 1}
		  {FD.disj V1 V2 1}
	  end
	  action: SATAction=
	  proc {$ I L}
	     {Browser clear}
	     {Browse dom(v1)}
	     {Browse L.1}
	     {Browse dom(v2)}
	     {Browse L.2.1}
	  end
	  ordering: Empty
      )
  demo(text:'SAT, pruning'
       script:
	  proc {$ X}
	     [V1 V2]=X
	  in
	     X:::0#1
	     {FD.disj {FD.nega V1} V2 1}
	     {FD.disj V1 {FD.nega V2} 1}
	     {FD.disj V1 V2 1}
	     {FD.distribute naive X}
	  end
	  action: SATAction
	  ordering: Empty
      )
  demo(text:'MONEY'
       script:
	  proc {$ Root}
	     S E N D M O R Y
	  in
	     Root = sol(s:S e:E n:N d:D m:M o:O r:R y:Y)
	     Root ::: 0#9
	     {FD.distinct Root}
	     S \=: 0 
	     M \=: 0
	     1000*S + 100*E + 10*N + D
	     +            1000*M + 100*O + 10*R + E
	     =: 10000*M + 1000*O + 100*N + 10*E + Y
	     {FD.distribute ff Root}
	  end
	  action:
	  proc {$ _ R}
	     MoneyWindow={New Tk.toplevel tkInit(title:'MONEY' parent:Window)}
	  in
	     row(                        3:{ML R s} 4:{ML R e} 5:{ML R n} 6:{ML R d})
	     #
	     row(           2:{TL '+'}   3:{ML R m} 4:{ML R o} 5:{ML R r} 6:{ML R e})
	     #
	     row(1:{TL '='} 2:{ML R m}   3:{ML R o} 4:{ML R n} 5:{ML R e} 6:{ML R y})
	     ={Grid MoneyWindow}
	  end
	  ordering: Empty
      )

  demo(text:'MOST MONEY'
       script:
	  proc {$ Root}
	     S E N D M O T Y
	  in
	     Root = sol(s:S e:E n:N d:D m:M o:O t:T y:Y)
	     Root ::: 0#9
	     {FD.distinct Root}
	     S \=: 0 
	     M \=: 0
	     1000*S + 100*E + 10*N + D
	     +            1000*M + 100*O + 10*S + T
	     =: 10000*M + 1000*O + 100*N + 10*E + Y
	     {FD.distribute ff Root}
	  end
	  action:
	  proc {$ _ R}
	     MoneyWindow={New Tk.toplevel tkInit(title:'MONEY' parent:Window)}
	  in
	     row(                        3:{ML R s} 4:{ML R e} 5:{ML R n} 6:{ML R d})
	     #
	     row(           2:{TL '+'}   3:{ML R m} 4:{ML R o} 5:{ML R s} 6:{ML R t})
	     #
	     row(1:{TL '='} 2:{ML R m}   3:{ML R o} 4:{ML R n} 5:{ML R e} 6:{ML R y})
	     ={Grid MoneyWindow}
	  end
	  ordering:
	  proc {$ Old New}
	     Old.m*10000 +  Old.o*1000+Old.n*100+Old.e*10+Old.y
	     <:
		New.m*10000+New.o*1000+New.n*100+New.e*10+New.y
	  end
      )
 demo(text:'Timetabling'
      script: TimetablingScript
      action: TimetablingGantt
      ordering:TimetablingOrdering
      intro:proc {$}
	       W={New Tk.toplevel tkInit(title:'Timetabling Problem Description'
					 parent:Window)}
	       T={New Tk.text tkInit(parent: W
				     font:MoneyFont
				    )}
	       F={New Open.file init(name:"c:\\henz\\talks\\pricai\\timetabling\\data.oz")}
	       ScheduleDataText={F read(size:all list:$)}
	    in
	       {T tk(ins p(0 0)
		     {Filter ScheduleDataText
		      fun {$ X} X\=&\r end}
		    )}
	       {Tk.send pack(T)}
	    end
     )

 demo(text:'Scheduling'
      script: BridgeScript
      action: BridgeGantt
      ordering:BridgeOrdering
      intro:proc {$}
	       W={New Tk.toplevel tkInit(title:'Scheduling Problem Description'
					 parent:Window)}
	       T={New Tk.text tkInit(parent: W
				     font:MoneyFont
				    )}
	       F={New Open.file init(name:"c:\\henz\\talks\\pricai\\bridge\\data.oz")}
	       ScheduleDataText={F read(size:all list:$)}
	       B={New Tk.button
		  tkInit(parent:W
			 text: "Show Example Schedule"
			 action:
			    proc {$}
			       thread
				  B = {New BridgeAnimation init}
			       in
				  {B setRepDelay(RepDelay)}
				  {B setRepAction(check)}
				  {Delay InitialDelay}
				  {B go}
			       end
			    end)}
	    in
	       {T tk(ins p(0 0)
		     {Filter ScheduleDataText
		      fun {$ X} X\=&\r end}
		    )}
	       {Tk.send pack(T B)}
	    end
     )

]
=
{ForAll $
 proc {$ Problem}
    L={New Tk.button
       tkInit(parent:Window
	      text:Problem.text
	      width:20
	      action:
		 proc {$}
		    case {HasFeature Problem intro}
		    then {Problem.intro} else skip
		    end
		    {Explorer script(Problem.script
				     Problem.ordering
				    )}
		    {Explorer add(information
				  Problem.action)}
		    {Explorer option(drawing hide: false
				     scale:true)}
		 end
	     )}
 in
    {Tk.send pack(L)}
 end}

CloseButton={New Tk.button
	     tkInit(parent:Window
		    text:'Close'
		    width:10
		    action:
		       proc {$}
			  {Window tkClose}
			  case {System.get standalone}
			  then {System.shutDown exit}
			  else skip
			  end
		       end)}
{Tk.send pack(CloseButton)}

{Tk.send wm(iconify Window)}
{TkFlush Window}
{Tk.send wm(deiconify Window)}
